==> 0.1.29.tar.gz: lib/network_resources/repository/product_repo.dart <==
import '../resources.dart';

import 'package:oowoo_core/network_resources/model/model.dart';

class ProductRepo {
  ProductRepo._();

  static ProductRepo? _instance;

  factory ProductRepo([AppApi? api]) {
    _instance ??= ProductRepo._();
    _instance!._api = api ?? AppApiImp();
    return _instance!;
  }

  late AppApi _api;

  Future<List<ProductCategory>> getProductCategories() async {
    NetworkResponse response = await _api.getProductCategories();
    return response.data ?? [];
  }

  Future<List<ProductStatus>> getStatusList() async {
    NetworkResponse response = await _api.getStatusList();
    return response.data ?? [];
  }

  Future<List<Product>> getProductsFromPro({categoryId, statusId}) async {
    NetworkResponse response = await _api.getProductsFromPro(
        categoryId: categoryId, statusId: statusId);
    return response.data ?? [];
  }

  Future<bool> updateTerminalFromPro({terminalId, label, direction}) async {
    Map params = {"terminalId": terminalId};
    if (direction != null) params.addAll({'direction': direction});
    if (label != null) params.addAll({'label': label});
    NetworkResponse response = await _api.updateTerminalFromPro(params);
    return response.data ?? false;
  }

  Future<bool> updateProduct(
      {productId, productStatusId, placeID, label}) async {
    Map params = {"productId": productId};
    if (label != null) params.addAll({'label': label});
    if (placeID != null) params.addAll({'placeID': placeID});
    if (productStatusId != null)
      params.addAll({'productStatusId': productStatusId});
    NetworkResponse response = await _api.updateProduct(params);
    return response.data ?? false;
  } 
}

==> 0.1.47.tar.gz: lib/network_resources/repository/product_repo.dart <==
import '../resources.dart';

import 'package:oowoo_core/network_resources/model/model.dart';

class ProductRepo {
  ProductRepo._();

  static ProductRepo? _instance;

  factory ProductRepo([AppApi? api]) {
    _instance ??= ProductRepo._();
    _instance!._api = api ?? AppApiImp();
    return _instance!;
  }

  late AppApi _api;

  Future<List<ProductCategory>> getProductCategories() async {
    NetworkResponse response = await _api.getProductCategories();
    return response.data ?? [];
  }

  Future<List<ProductStatus>> getStatusList() async {
    NetworkResponse response = await _api.getStatusList();
    return response.data ?? [];
  }

  Future<List<Product>> getProductsFromPro(params) async {
    NetworkResponse response = await _api.getProductsFromPro(params);
    return response.data ?? [];
  }

  Future<bool> updateTerminalFromPro({terminalId, label, direction}) async {
    Map params = {"terminalId": terminalId};
    if (direction != null) params.addAll({'direction': direction});
    if (label != null) params.addAll({'label': label});
    NetworkResponse response = await _api.updateTerminalFromPro(params);
    return response.data ?? false;
  }

  Future<bool> updateProduct(
      {productId, productStatusId, placeID, label}) async {
    Map params = {"productId": productId};
    if (label != null) params.addAll({'label': label});
    if (placeID != null) params.addAll({'placeID': placeID});
    if (productStatusId != null)
      params.addAll({'productStatusId': productStatusId});
    NetworkResponse response = await _api.updateProduct(params);
    return response.data ?? false;
  } 
}
